@@ -49,8 +49,9 @@
  *	if invoked with -v flag.
  */
 
-#include <global.h>
+#include <my_global.h>
 #include <m_string.h>
+#include <my_pthread.h>
 
 static char *my_name;
 static int verbose;
@@ -168,7 +169,7 @@ register unsigned long *child_time;
 	*name_pos = temp->pos;
 	*time_entered = temp->time;
 	*child_time = temp->children;
-	DBUG_PRINT ("pop", ("%d %d %d",*name_pos,*time_entered,*child_time));
+	DBUG_PRINT ("pop", ("%d %lu %lu",*name_pos,*time_entered,*child_time));
 	rtnval = stacktop--;
     }
     DBUG_RETURN (rtnval);
@@ -246,7 +247,7 @@ char *m_name;
 	modules[n_items].m_stkuse = 0;
 	DBUG_RETURN (n_items++);
     }
-    while (cmp = strcmp (m_name,modules[ind].name)) {
+    while ((cmp = strcmp (m_name,modules[ind].name))) {
 	if (cmp < 0) {	/* In left subtree */
 	    if (s_table[ind].lchild == MAXPROCS) {
 		/* Add as left child */
@@ -333,12 +334,12 @@ FILE *inf;
        * function is found on the stack.
        */
       while (pop (&oldpos, &oldtime, &oldchild)) {
-	DBUG_PRINT ("popped", ("%d %d", oldtime, oldchild));
+	DBUG_PRINT ("popped", ("%lu %lu", oldtime, oldchild));
 	time = fn_time - oldtime;
 	t = top ();
 	t -> children += time;
 	DBUG_PRINT ("update", ("%s", modules[t -> pos].name));
-	DBUG_PRINT ("update", ("%d", t -> children));
+	DBUG_PRINT ("update", ("%lu", t -> children));
 	time -= oldchild;
 	modules[oldpos].m_time += time;
 	modules[oldpos].m_calls++;
@@ -392,7 +393,7 @@ FILE *inf;
       }
       break;
     default:
-      fprintf (stderr, "unknown record type '%s'\n", buf[0]);
+      fprintf (stderr, "unknown record type '%c'\n", buf[0]);
       break;
     }
   next_line:;
@@ -450,10 +451,11 @@ FILE *outf;
 unsigned long int sum_calls, sum_time;
 {
     DBUG_ENTER ("out_trailer");
-    if (verbose) {
-	fprintf (outf, "======\t==========\t===========\t==========\t========\n");
-	fprintf (outf, "%6d\t%10.2f\t%11d\t%10.2f\t\t%-15s\n",
-		sum_calls, 100.0, sum_time, 100.0, "Totals");
+    if (verbose)
+    {
+      fprintf(outf, "======\t==========\t===========\t==========\t========\n");
+      fprintf(outf, "%6ld\t%10.2f\t%11ld\t%10.2f\t\t%-15s\n",
+              sum_calls, 100.0, sum_time, 100.0, "Totals");
     }
     DBUG_VOID_RETURN;
 }
@@ -488,16 +490,16 @@ unsigned long int *called, *timed;
     import = (unsigned int) (per_time * per_calls);
 
     if (verbose) {
-	fprintf (outf, "%6d\t%10.2f\t%11d\t%10.2f  %10d\t%-15s\n",
+	fprintf (outf, "%6d\t%10.2f\t%11ld\t%10.2f  %10d\t%-15s\n",
 		calls, per_calls, time, per_time, import, name);
     } else {
 	ms_per_call = time;
 	ms_per_call /= calls;
 	ftime = time;
 	ftime /= 1000;
-	fprintf (outf, "%8.2f%8.3f%8u%8.3f%8.2f%8u%8u  %-s\n",
-		per_time, ftime, calls, ms_per_call, per_calls, import,
-		 stkuse, name);
+	fprintf(outf, "%8.2f%8.3f%8u%8.3f%8.2f%8u%8lu  %-s\n",
+                per_time, ftime, calls, ms_per_call, per_calls, import,
+                stkuse, name);
     }
     *called = calls;
     *timed = time;
@@ -518,19 +520,19 @@ register unsigned long int *s_calls, *s_time;
     unsigned long int calls, time;
 
     DBUG_ENTER ("out_body");
-    DBUG_PRINT ("out_body", ("%d,%d",*s_calls,*s_time));
+    DBUG_PRINT ("out_body", ("%lu,%lu",*s_calls,*s_time));
     if (root == MAXPROCS) {
-	DBUG_PRINT ("out_body", ("%d,%d",*s_calls,*s_time));
+	DBUG_PRINT ("out_body", ("%lu,%lu",*s_calls,*s_time));
     } else {
 	while (root != MAXPROCS) {
 	    out_body (outf, s_table[root].lchild,s_calls,s_time);
 	    out_item (outf, &modules[s_table[root].pos],&calls,&time);
-	    DBUG_PRINT ("out_body", ("-- %d -- %d --", calls, time));
+	    DBUG_PRINT ("out_body", ("-- %lu -- %lu --", calls, time));
 	    *s_calls += calls;
 	    *s_time += time;
 	    root = s_table[root].rchild;
 	}
-	DBUG_PRINT ("out_body", ("%d,%d", *s_calls, *s_time));
+	DBUG_PRINT ("out_body", ("%lu,%lu", *s_calls, *s_time));
     }
     DBUG_VOID_RETURN;
 }
@@ -572,6 +574,11 @@ int main (int argc, char **argv)
     FILE *infile;
     FILE *outfile = {stdout};
 
+#if defined(HAVE_PTHREAD_INIT) && defined(THREAD)
+  pthread_init();                       /* Must be called before DBUG_ENTER */
+#endif
+  my_thread_global_init();
+  {
     DBUG_ENTER ("main");
     DBUG_PROCESS (argv[0]);
     my_name = argv[0];
@@ -601,6 +608,7 @@ int main (int argc, char **argv)
     output (outfile);
     DBUG_RETURN (EX_OK);
 }
+}
 
 #ifdef MSDOS
 
