@@ -1,11 +1,25 @@
-/* Copyright Abandoned 1996 TCX DataKonsult AB & Monty Program KB & Detron HB
-   This file is public domain and comes with NO WARRANTY of any kind */
+/* Copyright (C) 2000 MySQL AB
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
 /* USE_MY_STREAM isn't set because we can't thrust my_fclose! */
 
 #include "mysys_priv.h"
 #include "mysys_err.h"
 #include <errno.h>
+#include <stdio.h>
 
 #ifdef HAVE_FSEEKO
 #undef ftell
@@ -25,8 +39,8 @@ uint my_fread(FILE *stream, byte *Buffer, uint Count, myf MyFlags)
 {
   uint readbytes;
   DBUG_ENTER("my_fread");
-  DBUG_PRINT("my",("stream: %lx  Buffer: %lx  Count: %u  MyFlags: %d",
-		   stream, Buffer, Count, MyFlags));
+  DBUG_PRINT("my",("stream: 0x%lx  Buffer: 0x%lx  Count: %u  MyFlags: %d",
+		   (long) stream, (long) Buffer, Count, MyFlags));
 
   if ((readbytes = (uint) fread(Buffer,sizeof(char),(size_t) Count,stream))
       != Count)
@@ -42,7 +56,7 @@ uint my_fread(FILE *stream, byte *Buffer, uint Count, myf MyFlags)
 	my_error(EE_EOFERR, MYF(ME_BELL+ME_WAITTANG),
 		 my_filename(fileno(stream)),errno);
     }
-    my_errno=errno;
+    my_errno=errno ? errno : -1;
     if (ferror(stream) || MyFlags & (MY_NABP | MY_FNABP))
       DBUG_RETURN((uint) -1);			/* Return with error */
   }
@@ -66,8 +80,8 @@ uint my_fwrite(FILE *stream, const byte *Buffer, uint Count, myf MyFlags)
   uint errors;
 #endif
   DBUG_ENTER("my_fwrite");
-  DBUG_PRINT("my",("stream: %lx  Buffer: %lx  Count: %u  MyFlags: %d",
-		   stream, Buffer, Count, MyFlags));
+  DBUG_PRINT("my",("stream: 0x%lx  Buffer: 0x%lx  Count: %u  MyFlags: %d",
+		   (long) stream, (long) Buffer, Count, MyFlags));
 
 #if !defined(NO_BACKGROUND) && defined(USE_MY_STREAM)
   errors=0;
@@ -97,16 +111,18 @@ uint my_fwrite(FILE *stream, const byte *Buffer, uint Count, myf MyFlags)
 #endif
 #if !defined(NO_BACKGROUND) && defined(USE_MY_STREAM)
 #ifdef THREAD
-      if (*my_pthread_getspecific(int*,THR_KEY_abort))
+      if (my_thread_var->abort)
 	MyFlags&= ~ MY_WAIT_IF_FULL;		/* End if aborted by user */
 #endif
-      if (errno == ENOSPC && (MyFlags & MY_WAIT_IF_FULL))
+      if ((errno == ENOSPC || errno == EDQUOT) &&
+          (MyFlags & MY_WAIT_IF_FULL))
       {
-	if (!(errors++ % MY_WAIT_GIVE_USER_A_MESSAGE))
-	  my_error(EE_DISK_FULL,MYF(ME_BELL | ME_NOREFRESH));
-	sleep(MY_WAIT_FOR_USER_TO_FIX_PANIC);
-	VOID(my_fseek(stream,seekptr,MY_SEEK_SET,MYF(0)));
-	continue;
+        if (!(errors++ % MY_WAIT_GIVE_USER_A_MESSAGE))
+          my_error(EE_DISK_FULL,MYF(ME_BELL | ME_NOREFRESH),
+                   "[stream]",my_errno,MY_WAIT_FOR_USER_TO_FIX_PANIC);
+        VOID(sleep(MY_WAIT_FOR_USER_TO_FIX_PANIC));
+        VOID(my_fseek(stream,seekptr,MY_SEEK_SET,MYF(0)));
+        continue;
       }
 #endif
       if (ferror(stream) || (MyFlags & (MY_NABP | MY_FNABP)))
@@ -132,11 +148,12 @@ uint my_fwrite(FILE *stream, const byte *Buffer, uint Count, myf MyFlags)
 	/* Seek to position in file */
 	/* ARGSUSED */
 
-my_off_t my_fseek(FILE *stream, my_off_t pos, int whence, myf MyFlags)
+my_off_t my_fseek(FILE *stream, my_off_t pos, int whence,
+		  myf MyFlags __attribute__((unused)))
 {
   DBUG_ENTER("my_fseek");
-  DBUG_PRINT("my",("stream: %lx  pos: %lu  whence: %d  MyFlags: %d",
-		   stream, pos, whence, MyFlags));
+  DBUG_PRINT("my",("stream: 0x%lx  pos: %lu  whence: %d  MyFlags: %d",
+                   (long) stream, (long) pos, whence, MyFlags));
   DBUG_RETURN(fseek(stream, (off_t) pos, whence) ?
 	      MY_FILEPOS_ERROR : (my_off_t) ftell(stream));
 } /* my_seek */
@@ -145,11 +162,11 @@ my_off_t my_fseek(FILE *stream, my_off_t pos, int whence, myf MyFlags)
 	/* Tell current position of file */
 	/* ARGSUSED */
 
-my_off_t my_ftell(FILE *stream, myf MyFlags)
+my_off_t my_ftell(FILE *stream, myf MyFlags __attribute__((unused)))
 {
   off_t pos;
   DBUG_ENTER("my_ftell");
-  DBUG_PRINT("my",("stream: %lx  MyFlags: %d",stream, MyFlags));
+  DBUG_PRINT("my",("stream: 0x%lx  MyFlags: %d", (long) stream, MyFlags));
   pos=ftell(stream);
   DBUG_PRINT("exit",("ftell: %lu",(ulong) pos));
   DBUG_RETURN((my_off_t) pos);
