@@ -200,8 +200,26 @@ struct sql_ex_info
 #define EXECUTE_LOAD_QUERY_EXTRA_HEADER_LEN (4 + 4 + 4 + 1)
 #define EXECUTE_LOAD_QUERY_HEADER_LEN  (QUERY_HEADER_LEN + EXECUTE_LOAD_QUERY_EXTRA_HEADER_LEN)
 
-/*
-   Event header offsets;
+/* 
+  Max number of possible extra bytes in a replication event compared to a
+  packet (i.e. a query) sent from client to master;
+  First, an auxiliary log_event status vars estimation:
+*/
+#define MAX_SIZE_LOG_EVENT_STATUS (4 /* flags2 */   + \
+                                   8 /* sql mode */ + \
+                                   1 + 1 + 255 /* catalog */ + \
+                                   4 /* autoinc */ + \
+                                   6 /* charset */ + \
+                                   MAX_TIME_ZONE_NAME_LENGTH)
+#define MAX_LOG_EVENT_HEADER   ( /* in order of Query_log_event::write */ \
+  LOG_EVENT_HEADER_LEN + /* write_header */ \
+  QUERY_HEADER_LEN     + /* write_data */   \
+  EXECUTE_LOAD_QUERY_EXTRA_HEADER_LEN + /*write_post_header_for_derived */ \
+  MAX_SIZE_LOG_EVENT_STATUS + /* status */ \
+  NAME_LEN + 1)
+
+/* 
+   Event header offsets; 
    these point to places inside the fixed header.
 */
 
@@ -783,6 +801,7 @@ public:
   void print(FILE* file, PRINT_EVENT_INFO* print_event_info= 0);
 #endif
 
+  Query_log_event();
   Query_log_event(const char* buf, uint event_len,
                   const Format_description_log_event *description_event,
                   Log_event_type event_type);
@@ -806,6 +825,26 @@ public:
   /* Writes derived event-specific part of post header. */
 };
 
+
+/*****************************************************************************
+
+  Muted Query Log Event class
+
+  Pretends to Log SQL queries, but doesn't actually do so.
+
+ ****************************************************************************/
+class Muted_query_log_event: public Query_log_event
+{
+public:
+#ifndef MYSQL_CLIENT
+  Muted_query_log_event();
+
+  bool write(IO_CACHE* file) { return(false); };
+  virtual bool write_post_header_for_derived(IO_CACHE* file) { return FALSE; }
+#endif
+};
+
+
 #ifdef HAVE_REPLICATION
 
 /*****************************************************************************
